@@ -4,7 +4,7 @@ from pyngrok.installer import get_ngrok_bin
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "4.2.2"
+__version__ = "5.0.0"
 
 BIN_DIR = os.path.normpath(os.path.join(os.path.abspath(os.path.dirname(__file__)), "bin"))
 DEFAULT_NGROK_PATH = os.path.join(BIN_DIR, get_ngrok_bin())
@@ -12,14 +12,32 @@ DEFAULT_CONFIG_PATH = None
 
 DEFAULT_NGROK_CONFIG_PATH = os.path.join(os.path.expanduser("~"), ".ngrok2", "ngrok.yml")
 
+_default_pyngrok_config = None
+
 
 class PyngrokConfig:
     """
     An object containing ``pyngrok``'s configuration for interacting with the ``ngrok`` binary. All values are
     optional when it is instantiated, and default values will be used for parameters not passed.
 
-    On import, ``conf.DEFAULT_PYNGROK_CONFIG`` is instantiated to a :class:`~pyngrok.conf.PyngrokConfig` with default values. When ``pyngrok_config`` is
-    not passed to methods in :mod:`~pyngrok.ngrok`, this default will be used.
+    Use :func:`~pyngrok.conf.get_default` and :func:`~pyngrok.conf.set_default` to interact with the default
+    ``pyngrok_config``, or pass another instance of this object as the ``pyngrok_config`` keyword arg to most
+    methods in the :mod:`~pyngrok.ngrok` module to override the default.
+
+    .. code-block:: python
+
+        from pyngrok import conf, ngrok
+
+        # Here we update the entire default config
+        pyngrok_config = conf.PyngrokConfig(ngrok_path="/usr/local/bin/ngrok")
+        conf.set_default(pyngrok_config)
+
+        # Here we update just one variable in the default config
+        conf.get_default().ngrok_path = "/usr/local/bin/ngrok"
+
+        # Here we leave the default config as-is and pass an override
+        pyngrok_config = conf.PyngrokConfig(ngrok_path="/usr/local/bin/ngrok")
+        ngrok.connect(pyngrok_config=pyngrok_config)
 
     :var ngrok_path: The path to the ``ngrok`` binary, defaults to the value in
         `conf.DEFAULT_NGROK_PATH <index.html#config-file>`_
@@ -69,15 +87,29 @@ class PyngrokConfig:
         self.start_new_session = start_new_session
 
 
-DEFAULT_PYNGROK_CONFIG = PyngrokConfig()
-
-
 def get_default():
     """
     Get the default config to be used with methods in the :mod:`~pyngrok.ngrok` module. To override the
-    default individually, the ``pyngrok_config`` keyword arg can also be passed to most of these methods.
+    default individually, the ``pyngrok_config`` keyword arg can also be passed to most of these methods,
+    or set a new default config with :func:`~pyngrok.conf.set_default`.
 
     :return: The default ``pyngrok_config``.
     :rtype: PyngrokConfig
     """
-    return DEFAULT_PYNGROK_CONFIG
+    if _default_pyngrok_config is None:
+        set_default(PyngrokConfig())
+
+    return _default_pyngrok_config
+
+
+def set_default(pyngrok_config):
+    """
+    Set a new default config to be used with methods in the :mod:`~pyngrok.ngrok` module. To override the
+    default individually, the ``pyngrok_config`` keyword arg can also be passed to most of these methods.
+
+    :param pyngrok_config: The new ``pyngrok_config`` to be used by default.
+    :type pyngrok_config: PyngrokConfig
+    """
+    global _default_pyngrok_config
+
+    _default_pyngrok_config = pyngrok_config
