@@ -13,8 +13,8 @@ from pyngrok import process, conf, installer
 from pyngrok.exception import PyngrokNgrokHTTPError, PyngrokNgrokURLError, PyngrokSecurityError, PyngrokError
 
 __author__ = "Alex Laird"
-__copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "5.0.0"
+__copyright__ = "Copyright 2021, Alex Laird"
+__version__ = "5.0.2"
 
 logger = logging.getLogger(__name__)
 
@@ -164,7 +164,7 @@ def get_ngrok_process(pyngrok_config=None):
 
 def connect(addr=None, proto=None, name=None, pyngrok_config=None, **options):
     """
-    Establish a new ``ngrok`` tunnel for the given protocol to the given port, returning a object representing
+    Establish a new ``ngrok`` tunnel for the given protocol to the given port, returning an object representing
     the connected tunnel.
 
     If a `tunnel definition in ngrok's config file <https://ngrok.com/docs#tunnel-definitions>`_ matches the given
@@ -178,6 +178,12 @@ def connect(addr=None, proto=None, name=None, pyngrok_config=None, **options):
     If ``ngrok`` is not running, calling this method will first start a process with
     :class:`~pyngrok.conf.PyngrokConfig`.
 
+    .. note::
+
+        ``ngrok``'s default behavior for ``http`` when no additional properties are passed is to open *two* tunnels,
+        one ``http`` and one ``https``. This method will return a reference to the ``http`` tunnel in this case. If
+        only a single tunnel is needed, pass ``bind_tls=True``.
+
     :param addr: The local port to which the tunnel will forward traffic, or a
         `local directory or network address <https://ngrok.com/docs#http-file-urls>`_, defaults to "80".
     :type addr: str, optional
@@ -250,7 +256,7 @@ def connect(addr=None, proto=None, name=None, pyngrok_config=None, **options):
                                      timeout=pyngrok_config.request_timeout),
                          pyngrok_config, api_url)
 
-    if proto == "http" and not options.get("bind_tls", False):
+    if proto == "http" and options.get("bind_tls", "both") == "both":
         tunnel = NgrokTunnel(api_request("{}{}%20%28http%29".format(api_url, tunnel.uri), method="GET",
                                          timeout=pyngrok_config.request_timeout),
                              pyngrok_config, api_url)
